==> ui-vue-commons-1.0.0.tgz: package/src/global/models/DialogMixin.ts <==
import {
    value,
    Wrapper,
    onBeforeMount,
    onMounted,
    computed,
} from 'vue-function-api';
import { IFormInputs, IDialogButtons, IVueDialog } from '@/global/models/types';

export default (data: IVueDialog, emit: any, $refs: any) => {
    const dialog = value(false);
    const loading = value(false);
    const inputs: Wrapper<IFormInputs[]> = value([]);
    const buttons: Wrapper<Array<string | IDialogButtons>> = value([]);
    const values: Wrapper<any> = value({});
    const loadings: Wrapper<any> = value({});
    const error = value('');

    onBeforeMount(() => {
        if (data.inputs) {
            inputs.value = data.inputs;
            const defaults: any = {};
            inputs.value.forEach((r) => {
                if (r.default) {
                    defaults[r.name] = r.default;
                }
            });
            values.value = defaults;
        }
        setLoadings();

        buttons.value = data.buttons;
    });

    onMounted(() => {
        dialog.value = true;
    });

    const setLoadings = () => {
        const ctxLoadings: any = {};
        buttons.value.forEach((r, index) => {
            ctxLoadings[index] = false;
        });
        loadings.value = ctxLoadings;
    };
    const close = (ctxError?: any) => {
        if (!ctxError) {
            dialog.value = false;
            setTimeout(() => emit('close'), 400);
        } else {
            if (typeof ctxError === 'string') {
                error.value = ctxError;
            } else {
                error.value = 'Sucedio un error';
            }
            loading.value = false;
            setLoadings();
        }
    };

    const action = (ev: any, index: any) => {
        if (ev) {
            const refs: any = $refs.form;
            error.value = '';
            if (refs && refs.validate()) {
                loading.value = true;
                const ctxLoadings: any = {};
                ctxLoadings[index] = true;
                loadings.value = ctxLoadings;
                const models: any = Object.assign({}, values.value);
                inputs.value.forEach((r: any) => {
                    if (r.number) {
                        models[r.name] = parseFloat(models[r.name]);
                    }
                });
                ev(close, Object.assign({}, models));
            } else {
                error.value = 'Completa todos los datos';
            }
        } else {
            close();
        }
    };

    const slots = computed(() => ({
        items: inputs.value
            .filter((v) => v.slotItem)
            .map((r) => ({ ...r, slot: `${r.name}.item` })),
        selection: inputs.value
            .filter((v) => v.slotSelection)
            .map((r) => ({
                ...r,
                slot: `${r.name}.selection`,
            })),
        labels: inputs.value
            .filter((v) => v.slotLabel)
            .map((r) => ({
                ...r,
                slot: `${r.name}.label`,
            })),
    }));

    return {
        dialog,
        loading,
        inputs,
        buttons,
        values,
        loadings,
        error,
        slots,
        action,
        close,
    };
};

==> ui-vue-commons-1.0.1.tgz: package/src/global/models/DialogMixin.ts <==
import {
    value,
    Wrapper,
    onBeforeMount,
    onMounted,
    computed,
} from 'vue-function-api';
import { IFormInputs, IDialogButtons, IVueDialog } from './types';

export default (data: IVueDialog, emit: any, $refs: any) => {
    const dialog = value(false);
    const loading = value(false);
    const inputs: Wrapper<IFormInputs[]> = value([]);
    const buttons: Wrapper<Array<string | IDialogButtons>> = value([]);
    const values: Wrapper<any> = value({});
    const loadings: Wrapper<any> = value({});
    const error = value('');

    onBeforeMount(() => {
        if (data.inputs) {
            inputs.value = data.inputs;
            const defaults: any = {};
            inputs.value.forEach((r) => {
                if (r.default) {
                    defaults[r.name] = r.default;
                }
            });
            values.value = defaults;
        }
        setLoadings();

        buttons.value = data.buttons;
    });

    onMounted(() => {
        dialog.value = true;
    });

    const setLoadings = () => {
        const ctxLoadings: any = {};
        buttons.value.forEach((r, index) => {
            ctxLoadings[index] = false;
        });
        loadings.value = ctxLoadings;
    };
    const close = (ctxError?: any) => {
        if (!ctxError) {
            dialog.value = false;
            setTimeout(() => emit('close'), 400);
        } else {
            if (typeof ctxError === 'string') {
                error.value = ctxError;
            } else {
                error.value = 'Sucedio un error';
            }
            loading.value = false;
            setLoadings();
        }
    };

    const action = (ev: any, index: any) => {
        if (ev) {
            const refs: any = $refs.form;
            error.value = '';
            if (refs && refs.validate()) {
                loading.value = true;
                const ctxLoadings: any = {};
                ctxLoadings[index] = true;
                loadings.value = ctxLoadings;
                const models: any = Object.assign({}, values.value);
                inputs.value.forEach((r: any) => {
                    if (r.number) {
                        models[r.name] = parseFloat(models[r.name]);
                    }
                });
                ev(close, Object.assign({}, models));
            } else {
                error.value = 'Completa todos los datos';
            }
        } else {
            close();
        }
    };

    const slots = computed(() => ({
        items: inputs.value
            .filter((v) => v.slotItem)
            .map((r) => ({ ...r, slot: `${r.name}.item` })),
        selection: inputs.value
            .filter((v) => v.slotSelection)
            .map((r) => ({
                ...r,
                slot: `${r.name}.selection`,
            })),
        labels: inputs.value
            .filter((v) => v.slotLabel)
            .map((r) => ({
                ...r,
                slot: `${r.name}.label`,
            })),
    }));

    return {
        dialog,
        loading,
        inputs,
        buttons,
        values,
        loadings,
        error,
        slots,
        action,
        close,
    };
};
